#include <iostream>
#include <fstream>
#include <vector>
#include <cmath>
#include <map>
#include <set>
#include <queue>
#include <complex>

using namespace std;

#define FOR(i, x, n)       for(int i=(x); i<(n); i++)
#define FR(i, n)           FOR(i, 0, n)
#define SZ                 size()
#define PB                 push_back
#define MP                 make_pair
#define FRI(it, v)         for(__typeof(v.begin()) it=v.begin(); it!=v.end(); it++)
#define sqr(x)             ( (x) * (x) )

typedef long long LL;
typedef pair<int, int> pr;

const int maxn = 1100;
const double eps = 1e-8;


namespace convexhull {

  const int maxn = 1000000;

  struct Point {
    int x, y;
    Point(int xx=0, int yy=0) { x=xx; y=yy; }
  };

  int n;
  Point p[maxn];
  bool mark[maxn];
  int k;
  int index[maxn];

  Point operator-(const Point &a, const Point &b)
  {
    return Point(a.x-b.x, a.y-b.y);
  }

  int sign(LL l)
  {
    return (l<0)?-1:(l==0?0:1);
  }

  int leftturn(const Point &a, const Point &b, const Point &c)
  {
    Point x = a-b;
    Point y = b-c;
    return sign(((LL)x.y*y.x - (LL)x.x*y.y));
  }

  LL dist(const Point &a, const Point &b)
  {
    return sqr((LL)a.x-b.x)+sqr((LL)a.y-b.y);
  }

  void convexhull()
  {
    k = 0;
    if(n == 0)
      return ;
    memset(mark, 0, sizeof mark);
    int q=0;
    for(int i=0; i<n; i++)
      if(p[i].x < p[q].x || (p[i].x == p[q].x && p[i].y < p[q].y))
	q = i;
    mark[q] = true;
    index[k++] = q;
    do {
      int j=index[0];
      for(int i=0; i<n; i++)
	if(!mark[i]) {
	  int d = leftturn(p[j], p[index[k-1]], p[i]);
	  if(d > 0)
	    j = i;
	  else
	    if(d == 0 && dist(p[index[k-1]], p[i]) > dist(p[index[k-1]], p[j]))
	      j = i;
	}
      mark[j] = true;
      index[k++] = j;
    } while (index[k-1] != index[0]);
  }

};



ifstream fin("cheese.in");
ofstream fout("input.txt");

int n;
int x[maxn], y[maxn], v[maxn];

bool eq(double x, double y)
{
  return fabs(x-y) < eps;
}

double dist(double x1, double y1, double x2, double y2)
{
  return sqrt( sqr(x1-x2) + sqr(y1-y2) );
}

double crosstime(int i, int j)
{
  return dist(x[i], y[i], x[j], y[j]) / (v[i] + v[j]);
}

struct FEL {
  double t;
  int a, b;
  FEL(int aa=0, int bb=0)
  {
    a = min(aa, bb);
    b = max(aa, bb);
    t = crosstime(a, b);
  }
};

bool operator<(FEL a, FEL b)
{
  if(fabs(a.t - b.t) > eps)
    return a.t < b.t;
  if(a.a != b.a)
    return a.a < b.a;
  return a.b < b.b;
}

set<FEL> fel;
bool mark[maxn];

vector<int> solve()
{
  vector<int> ans;
  memset(mark, 0, sizeof mark);

  fel.clear();
  FR(i, n) FOR(j, i+1, n)
    fel.insert(FEL(i, j));

  while(!fel.empty()) {
    set<int> dead;
    dead.clear();
    double t = fel.begin()->t;
    while(eq(fel.begin()->t, t)) {
      FEL cur = *fel.begin();
      fel.erase(fel.begin());
      dead.insert(cur.a);
      dead.insert(cur.b);
    }
    FRI(j, dead) {
      FR(i, n) {
	fel.erase(FEL(i, *j));
	fel.erase(FEL(*j, i));
      }
      mark[*j] = true;
      ans.PB(*j+1);
    }
  }
  FR(i, n)
    if(!mark[i])
      ans.PB(i+1);

  return ans;
}

FEL myfel[maxn*maxn];

vector<int> solve2()
{
  set<pair<double, int> > deadtime;
  vector<int> ans;
  memset(mark, 0, sizeof mark);

  int m=0;
  FR(i, n) FOR(j, i+1, n)
    myfel[m++] = FEL(i, j);

  sort(myfel, myfel+m);

  for(int i=0; i<m; ) {
    set<int> dead;
    dead.clear();
    double t = myfel[i].t;
    while(i<m && eq(myfel[i].t, t)) {
      FEL cur = myfel[i];
      i ++;
      if(!mark[cur.a] && !mark[cur.b]) {
	dead.insert(cur.a);
	dead.insert(cur.b);
      }
    }
    FRI(j, dead) {
      /*FR(i, n)
	fel.erase(FEL(i, *j));*/
      mark[*j] = true;
      ans.PB(*j+1);
    }

    /*FEL cur = myfel[i];
      if(!mark[cur.a] && !mark[cur.b]) {
      mark[cur.a] = true;
      mark[cur.b] = true;
      deadtime.insert(MP(cur.t, cur.a));
      deadtime.insert(MP(cur.t, cur.b));
      }*/
  }
  /*unsigned c=0;
    FRI(i, deadtime) {
    if(i != deadtime.begin() && !eq(((--i)++)->first, i->first)) {
    sort(ans.begin()+c, ans.end());
    c = ans.SZ;
    }
    ans.PB(i->second+1);
    }
    sort(ans.begin()+c, ans.end());*/
  FR(i, n)
    if(!mark[i])
      ans.PB(i+1);

  return ans;
}

vector<int> wrong_sol1()
{
  set<pair<double, int> > deadtime;
  vector<int> ans;
  memset(mark, 0, sizeof mark);

  fel.clear();
  FR(i, n) FOR(j, i+1, n)
    fel.insert(FEL(i, j));

  while(!fel.empty()) {
    FEL cur = *fel.begin();
    fel.erase(fel.begin());
    if(!mark[cur.a] && !mark[cur.b]) {
      if(!mark[cur.a]++)
	deadtime.insert(MP(cur.t, cur.a));
      if(!mark[cur.b]++)
	deadtime.insert(MP(cur.t, cur.b));
    }
  }

  unsigned c=0;
  FRI(i, deadtime) {
    ans.PB(i->second+1);
    if(i != deadtime.begin() && !eq(((--i)++)->first, i->first)) {
      sort(ans.begin()+c, ans.end());
      c = ans.SZ;
    }
  }
  sort(ans.begin()+c, ans.end());
  FR(i, n)
    if(!mark[i])
      ans.PB(i+1);

  return ans;
}

void gen(int n,
	 int minx, int maxx,
	 int minv, int maxv,
	 int mindist, int maxdist)
{
  convexhull::n = n*n;
  int cx = (minx+maxx) / 2;
  for(int i=0; i<n*n; i++) {
    double d;
    do {
      complex<double> p = polar(rand()%(maxdist-mindist+1)+(double) mindist,
				(rand()%100000)*M_PI*2/20000);
      /*convexhull::p[i].x = rand()%(maxx-minx+1) + minx;
	convexhull::p[i].y = rand()%(maxx-minx+1) + minx;*/
      convexhull::p[i].x = cx + real(p);
      convexhull::p[i].y = cx + imag(p);
      convexhull::p[i].x <?= 100000;
      convexhull::p[i].x >?= -100000;
      convexhull::p[i].y <?= 100000;
      convexhull::p[i].y >?= -100000;
      d = dist(convexhull::p[i].x, convexhull::p[i].y, cx, cx);
    } while( d < mindist || d > maxdist );
  }
  convexhull::convexhull();

  ::n = convexhull::k;
  ::n <?= maxn-1;
  for(int i=0; i< ::n; i++) {
    x[i] = convexhull::p[convexhull::index[i]].x;
    y[i] = convexhull::p[convexhull::index[i]].y;
    v[i] = rand()%(maxv-minv+1) + minv;
  }
}

void gencircle(int cx, int cy, int r, int n, double d, int minv, int maxv)
{
  convexhull::n = n;
  FR(i, n) {
    complex<double> p = polar((double) r, d*i);
    convexhull::p[i].x = cx + real(p);
    convexhull::p[i].y = cy + imag(p);
  }
  convexhull::convexhull();

  ::n = convexhull::k;
  for(int i=0; i< ::n; i++) {
    x[i] = convexhull::p[convexhull::index[i]].x;
    y[i] = convexhull::p[convexhull::index[i]].y;
    v[i] = rand()%(maxv-minv+1) + minv;
  }
}

void readfile()
{
  fin>>n;
  FR(i, n)
    fin>>x[i]>>y[i]>>v[i];
}

void writefile()
{
  fout<<n<<endl;
  FR(i, n)
    fout<<x[i]<<' '<<y[i]<<' '<<v[i]<<endl;
  static int count = 0;
  count ++;
  cout<<"n = "<<n<<endl;
  cout<<count<<" tests have writen to file."<<endl;
}

void generate()
{
  int t;
  fin>>t;
  fout<<(t+30)<<endl;
  FR(tt, t) {
    readfile();
    writefile();
  }
  gencircle(0, 0, 100000, 999, M_PI*2/1000, 1, 100000);
  writefile();
  gencircle(0, 0, 100000, 999, M_PI*2/2000, 1, 100);
  writefile();
  gencircle(0, 0, 100000, 999, M_PI*2/1000, 100000, 100000);
  writefile();
  gencircle(0, 0, 10000, 899, M_PI*2/1000, 10000, 100000);
  writefile();
  gencircle(0, 0, 1000, 799, M_PI*2/1000, 1000, 100000);
  writefile();
  gencircle(0, 0, 100, 10, M_PI*2/10, 1, 10);
  writefile();
  FR(i, 20) {
    int minv = rand()%100000;
    int maxv = rand()%100000;
    if(minv > maxv)
      swap(minv, maxv);
    int mind = rand()%100000;
    int maxd = rand()%100000;
    if(mind > maxd)
      swap(mind, maxd);
    gen(500, -(rand()%100000), (rand()%100000), 
	minv, maxv, mind, maxd);
    if(n <= 1000)
      writefile();
  }
}

int main()
{
  //   srand(time(0));
  //   generate();
  /*  int t;
      fin>>t;
      FR(tt, t) {
      //gen(100, -100000, 100000, 1, 100000, 80000, 100000);
      cout<<n<<endl;
      //readfile();
      vector<int> ans = solve();
      cout<<"AC = ";
      FR(i, ans.SZ) {
      if(i) cout<<' ';
      cout<<ans[i];
      }
      cout<<endl;

      ans = wrong_sol1();
      cout<<"W1 = ";
      FR(i, ans.SZ)
      cout<<ans[i]<<' ';
      cout<<endl;

      }*/
  int t;
  cin>>t;
  FR(tt, t) {
    cin>>n;
    FR(i, n)
      cin>>x[i]>>y[i]>>v[i];
    vector<int> ans = solve2();
    FR(i, ans.SZ) {
      if(i) cout<<' ';
      cout<<ans[i];
    }
    cout<<endl;
  }
  cerr<<clock()<<endl;
}
